package com.yanzhu.jh.project.service;

import java.util.List;
import com.yanzhu.jh.project.domain.SurProjectBuildNodeData;
import com.yanzhu.jh.project.domain.vo.SurProjectBuildNodeDataExport;

/**
 * 项目建设节点数据Service接口
 * 
 * @author ruoyi
 * @date 2023-08-07
 */
public interface ISurProjectBuildNodeDataService 
{
    /**
     * 查询项目建设节点数据
     * 
     * @param id 项目建设节点数据主键
     * @return 项目建设节点数据
     */
    public SurProjectBuildNodeData selectSurProjectBuildNodeDataById(Long id);

    /**
     * 查询项目建设节点数据列表
     * 
     * @param surProjectBuildNodeData 项目建设节点数据
     * @return 项目建设节点数据集合
     */
    public List<SurProjectBuildNodeData> selectSurProjectBuildNodeDataList(SurProjectBuildNodeData surProjectBuildNodeData);

    /**
     * 新增项目建设节点数据
     * 
     * @param surProjectBuildNodeData 项目建设节点数据
     * @return 结果
     */
    public int insertSurProjectBuildNodeData(SurProjectBuildNodeData surProjectBuildNodeData);

    /**
     * 修改项目建设节点数据
     * 
     * @param surProjectBuildNodeData 项目建设节点数据
     * @return 结果
     */
    public int updateSurProjectBuildNodeData(SurProjectBuildNodeData surProjectBuildNodeData);

    /**
     * 批量删除项目建设节点数据
     * 
     * @param ids 需要删除的项目建设节点数据主键集合
     * @return 结果
     */
    public int deleteSurProjectBuildNodeDataByIds(Long[] ids);

    /**
     * 删除项目建设节点数据信息
     * 
     * @param id 项目建设节点数据主键
     * @return 结果
     */
    public int deleteSurProjectBuildNodeDataById(Long id);

    public int addProjectNodes(long projectId);

    public int importData(List<SurProjectBuildNodeDataExport> list);

    /**
     * 节点计划预警
     * @param where
     * @return
     */
    public  List<SurProjectBuildNodeData> selectScheduledAlerts(SurProjectBuildNodeData where);

    /**
     * 获取当前节点及叶子节点
     * @param where
     * @return
     */
    public  List<SurProjectBuildNodeData> selectCurrent(SurProjectBuildNodeData where);

    public  List<SurProjectBuildNodeData> countCompletionRate(SurProjectBuildNodeData where);

    public List<SurProjectBuildNodeData> queryByProjectType(long type);
}
